@@ -6,7 +6,7 @@ use Carp ();
 use Encode ();
 
 use vars qw($VERSION);
-our $VERSION = '6.07';
+our $VERSION = '6.08';
 
 my %form_tags = map {$_ => 1} qw(input textarea button select option);
 
@@ -953,6 +953,7 @@ sub click
     my($self,$form,$x,$y) = @_;
     for ($x, $y) { $_ = 1 unless defined; }
     local($self->{clicked}) = [$x,$y];
+    local($self->{value})   = "" unless defined $self->value;
     return $form->make_request;
 }
 
@@ -1030,7 +1031,8 @@ sub form_name_value {
     my $filename = $self->filename;
     my @headers = $self->headers;
     my $content = $self->content;
-    if (defined $content) {
+    my %headers = @headers;
+    if (defined $content || grep m/^Content$/i, keys %headers) {
 	$filename = $file unless defined $filename;
 	$file = undef;
 	unshift(@headers, "Content" => $content);
@@ -1045,7 +1047,7 @@ sub form_name_value {
 	my $fn = shift @$file;
 	push(@headers, @$file);
 	$file = $f;
-	$filename = $fn unless defined $filename;
+	$filename = $fn;
     }
 
     return ($name => [$file, $filename, @headers]);
@@ -1078,7 +1080,7 @@ HTML::Form - Class that represents an HTML form element
 
 =head1 VERSION
 
-version 6.07
+version 6.08
 
 =head1 SYNOPSIS
 
